summaryrefslogtreecommitdiffhomepage
path: root/examples/models/models_heightmap.c
diff options
context:
space:
mode:
authorraysan5 <[email protected]>2017-07-21 09:55:10 +0200
committerraysan5 <[email protected]>2017-07-21 09:55:10 +0200
commit163339991c48241e64b63031093799bb613f086a (patch)
tree12c2ed7c41be5d299b1c649c264c56bdf5ffe13f /examples/models/models_heightmap.c
parent92729662f42f62156bcac3c1d21fbb57b7810b64 (diff)
downloadraylib-163339991c48241e64b63031093799bb613f086a.tar.gz
raylib-163339991c48241e64b63031093799bb613f086a.zip
Review heightmap example for raylib 1.8
Diffstat (limited to 'examples/models/models_heightmap.c')
-rw-r--r--examples/models/models_heightmap.c18
1 files changed, 10 insertions, 8 deletions
diff --git a/examples/models/models_heightmap.c b/examples/models/models_heightmap.c
index 10069e03..e887cea7 100644
--- a/examples/models/models_heightmap.c
+++ b/examples/models/models_heightmap.c
@@ -23,11 +23,14 @@ int main()
// Define our custom camera to look into our 3d world
Camera camera = {{ 18.0f, 16.0f, 18.0f }, { 0.0f, 0.0f, 0.0f }, { 0.0f, 1.0f, 0.0f }, 45.0f };
- Image image = LoadImage("resources/heightmap.png"); // Load heightmap image (RAM)
- Texture2D texture = LoadTextureFromImage(image); // Convert image to texture (VRAM)
- Model map = LoadHeightmap(image, (Vector3){ 16, 8, 16 }); // Load heightmap model with defined size
- map.material.texDiffuse = texture; // Set map diffuse texture
- Vector3 mapPosition = { -8.0f, 0.0f, -8.0f }; // Set model position (depends on model scaling!)
+ Image image = LoadImage("resources/heightmap.png"); // Load heightmap image (RAM)
+ Texture2D texture = LoadTextureFromImage(image); // Convert image to texture (VRAM)
+
+ Mesh mesh = GenMeshHeightmap(image, (Vector3){ 16, 8, 16 }); // Generate heightmap mesh (RAM and VRAM)
+ Model model = LoadModelFromMesh(mesh); // Load model from generated mesh
+
+ model.material.maps[MAP_DIFFUSE].texture = texture; // Set map diffuse texture
+ Vector3 mapPosition = { -8.0f, 0.0f, -8.0f }; // Define model position
UnloadImage(image); // Unload heightmap image from RAM, already uploaded to VRAM
@@ -52,8 +55,7 @@ int main()
Begin3dMode(camera);
- // NOTE: Model is scaled to 1/4 of its original size (128x128 units)
- DrawModel(map, mapPosition, 1.0f, RED);
+ DrawModel(model, mapPosition, 1.0f, RED);
DrawGrid(20, 1.0f);
@@ -71,7 +73,7 @@ int main()
// De-Initialization
//--------------------------------------------------------------------------------------
UnloadTexture(texture); // Unload texture
- UnloadModel(map); // Unload model
+ UnloadModel(model); // Unload model
CloseWindow(); // Close window and OpenGL context
//--------------------------------------------------------------------------------------